@@ -4,13 +4,20 @@ from weaverbird.backends.sql_translator.types import SQLQuery, SQLStepTranslatio
 from weaverbird.pipeline import Pipeline, PipelineStep
 
 from .steps import sql_steps_translators
-from .types import SQLPipelineTranslationReport, SQLQueryDescriber, SQLQueryRetriever
+from .types import (
+    SQLPipelineTranslationReport,
+    SQLQueryDescriber,
+    SQLQueryExecutor,
+    SQLQueryRetriever,
+)
 
 
 def translate_pipeline(
     pipeline_to_translate: Pipeline,
     sql_query_retriever: SQLQueryRetriever,  # TODO : rename it to sql_table_retriever when ready
     sql_query_describer: SQLQueryDescriber,
+    sql_query_executor: SQLQueryExecutor,
+    subcall_from_other_pipeline_count: int = None,
 ) -> Tuple[SQLQuery, SQLPipelineTranslationReport]:
     """
     The main function of the module. Translates a pipeline and returns the result as a transformed query.
@@ -31,9 +38,12 @@ def translate_pipeline(
                 index,
                 sql_query_retriever=sql_query_retriever,
                 sql_query_describer=sql_query_describer,
+                sql_query_executor=sql_query_executor,
                 sql_translate_pipeline=translate_pipeline,
+                subcall_from_other_pipeline_count=subcall_from_other_pipeline_count,
             )
             translate_report.append(SQLStepTranslationReport(step_index=index))
+
         except Exception as e:
             raise SQLPipelineTranslationFailure(step, index, e) from e
 
